@@ -349,7 +349,8 @@ class TranslateJson(object):
                 register_data += line + "\n<br>"
     
     
-        table_title = 'Register:' + name.split("@")[-1] + ' ('  + addr + ')'
+        #table_title = 'Register:' + name.split("@")[-1] + ' ('  + addr + ')'
+        table_title = 'Register:' + name + ' ('  + addr + ')'
         #print(table_title)
         #register_data = "## " + '<center>' + table_title + '</center>\n\n' +\
         register_data = "## " + name + "\n" + '<center>' + table_title + '</center>\n\n' +\
@@ -393,9 +394,7 @@ class TranslateJson(object):
                     fd.write("   ")
             with open(summery, 'w') as fd:
                 fd.write('# Summary \n\n')
-                fd.write('* [寄存器介绍](README.md)\n')
-                fd.write('* [' + self.js_dict['module name'] + ']('+ self.js_dict['module name'] + '.md)\n')
-                fd.write('  * [寄存器列表](all_register.md)\n')
+                fd.write('* [寄存器介绍](all_register.md)\n')
                 for i in range(int(len(self.js_dpath))):
                     name = self.get_delem(self.js_dict, self.js_dpath[i], key = 'RegName' )
                     name = name.upper()
@@ -403,11 +402,11 @@ class TranslateJson(object):
                         dpath = self.js_dpath[i]
                         if dpath.find("group_reg") >= 0:
                             is_group = 1
-                            group_list = self.get_group_path(dpath)
-                            for g in group_list:
-                                gname = self.get_delem(self.js_dict, g, key="RegName")
-                                gname = gname.upper()
-                                name = gname + "@" + name
+                            #group_list = self.get_group_path(dpath)
+                            #for g in group_list:
+                            #    gname = self.get_delem(self.js_dict, g, key="RegName")
+                            #    gname = gname.upper()
+                            #    name = gname + "@" + name
                         fd.write('  * [' + name + ']('+ name + '.md)\n')
                         self.create_md3(self.js_dpath[i], lm)
                 with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
